<?php
/**
 * Zion Blog Theme Customizer
 *
 * @package Zion_Blog
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
*/
function zion_blog_customize_register($wp_customize)
{
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';
    $wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

    $zion_blog_options = zion_blog_theme_options();

    if (isset($wp_customize->selective_refresh)) {
        $wp_customize->selective_refresh->add_partial('blogname', [
            'selector' => '.site-title a',
            'render_callback' => 'zion_blog_customize_partial_blogname',
        ]);
        $wp_customize->selective_refresh->add_partial('blogdescription', [
            'selector' => '.site-description',
            'render_callback' => 'zion_blog_customize_partial_blogdescription',
        ]);
    }

    $wp_customize->add_panel('theme_options', [
        'title' => esc_html__('Theme Options', 'zion-blog'),
        'priority' => 2,
    ]);

    /* Header Section */
    $wp_customize->add_section('header_section', [
        'title' => esc_html__('Header Section', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);

    $wp_customize->add_setting('zion_blog_theme_options[facebook]', [
        'type' => 'option',
        'default' => $zion_blog_options['facebook'],
        'sanitize_callback' => 'zion_blog_sanitize_url',
    ]);
    $wp_customize->add_control('zion_blog_theme_options[facebook]', [
        'label' => esc_html__('Facebook Link', 'zion-blog'),
        'type' => 'url',
        'section' => 'header_section',
        'settings' => 'zion_blog_theme_options[facebook]',
    ]);

    $wp_customize->add_setting('zion_blog_theme_options[pinterest]', [
        'type' => 'option',
        'default' => $zion_blog_options['pinterest'],
        'sanitize_callback' => 'zion_blog_sanitize_url',
    ]);
    $wp_customize->add_control('zion_blog_theme_options[pinterest]', [
        'label' => esc_html__('pinterest Link', 'zion-blog'),
        'type' => 'url',
        'section' => 'header_section',
        'settings' => 'zion_blog_theme_options[pinterest]',
    ]);




    $wp_customize->add_section('main_banner_section', [
        'title' => esc_html__('Main Banner', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);
    $wp_customize->add_setting(
        'zion_blog_theme_options[main_banner_category]',
        [
            'type' => 'option',
            'sanitize_callback' => 'zion_blog_sanitize_select',
            'default' => $zion_blog_options['main_banner_category'],
        ]
    );

    $wp_customize->add_control(
        'zion_blog_theme_options[main_banner_category]',
        [
            'section' => 'main_banner_section',
            'type' => 'select',
            'choices' => zion_blog_get_categories_select(),
            'label' => esc_html__('Select Category to show Posts', 'zion-blog'),
            'description' => esc_html__(
                'Max 3 Posts will be shown from the selected Category in Free Version',
                'zion-blog'
            ),
            'settings' => 'zion_blog_theme_options[main_banner_category]',
            'priority' => 1,
        ]
    );


    //radio box sanitization function
    function zion_blog_sanitize_radio( $input, $setting ){

        //input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only
        $input = sanitize_key($input);

        //get the list of possible radio box options
        $choices = $setting->manager->get_control( $setting->id )->choices;

        //return input if valid or return default option
        return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

    }
    $wp_customize->add_section('below_banner_section', [
        'title' => esc_html__('Blog Carousel Section', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);

    $wp_customize->add_setting('zion_blog_theme_options[top_section_title]',
    array(
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('top_section_title',
    array(
        'label' => esc_html__('Section Title', 'zion-blog'),
        'type' => 'text',
        'section' => 'below_banner_section',
        'settings' => 'zion_blog_theme_options[top_section_title]',
    )
);


    $wp_customize->add_setting('zion_blog_theme_options[show_first_blog_carousel]', [
        'type' => 'option',
        'default' => true,
        'default' => $zion_blog_options['show_first_blog_carousel'],
        'sanitize_callback' => 'zion_blog_sanitize_checkbox',
    ]);

    $wp_customize->add_control('zion_blog_theme_options[show_first_blog_carousel]', [
        'label' => esc_html__('Show First Blog Carousel', 'zion-blog'),
        'type' => 'Checkbox',
        'priority' => 1,
        'section' => 'below_banner_section',
    ]);

    $wp_customize->add_setting(
        'zion_blog_theme_options[blog_carousel_category]',
        [
            'type' => 'option',
            'sanitize_callback' => 'zion_blog_sanitize_select',
            'default' => $zion_blog_options['blog_carousel_category'],
        ]
    );

    $wp_customize->add_control(
        'zion_blog_theme_options[blog_carousel_category]',
        [
            'section' => 'below_banner_section',
            'type' => 'select',
            'choices' => zion_blog_get_categories_select(),
            'label' => esc_html__('Select Category to show Posts', 'zion-blog'),
            'description' => esc_html__(
                'Max 5 Posts will be shown from the selected Category in Free Version',
                'zion-blog'
            ),
            'settings' => 'zion_blog_theme_options[blog_carousel_category]',
            'priority' => 1,
        ]
    );

    function zion_blog_sanitize_checkbox($input)
    {
        if (true === $input) {
            return 1;
        } else {
            return 0;
        }
    }





    $wp_customize->add_section('blog_sidebar_section', [
        'title' => esc_html__('Homepage Sidebar Section', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);
    $wp_customize->add_setting('zion_blog_theme_options[sidebar_section_title]',
    array(
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('sidebar_section_title',
    array(
        'label' => esc_html__('Section Title', 'zion-blog'),
        'type' => 'text',
        'section' => 'blog_sidebar_section',
        'settings' => 'zion_blog_theme_options[sidebar_section_title]',
    )
);

    $wp_customize->add_setting(
        'zion_blog_theme_options[sidebar_blog_category]',
        [
            'default' => $zion_blog_options['sidebar_blog_category'],
            'type' => 'option',
            'sanitize_callback' => 'zion_blog_sanitize_select',
            'capability' => 'edit_theme_options',
        ]
    );

    $wp_customize->add_control(
        new zion_blog_Dropdown_Customize_Control(
            $wp_customize,
            'zion_blog_theme_options[sidebar_blog_category]',
            [
                'label' => esc_html__('Select Blog Posts Category', 'zion-blog'),
                'section' => 'blog_sidebar_section',
                'choices' => zion_blog_get_categories_select(),
                'settings' => 'zion_blog_theme_options[sidebar_blog_category]',
            ]
        )
    );




    $wp_customize->add_section('second_blog_carousel_section', [
        'title' => esc_html__('Second Blog Carousel Section', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);
    $wp_customize->add_setting('zion_blog_theme_options[second_blog_section_title]',
    array(
        'type' => 'option',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('second_blog_section_title',
    array(
        'label' => esc_html__('Section Title', 'zion-blog'),
        'type' => 'text',
        'section' => 'second_blog_carousel_section',
        'settings' => 'zion_blog_theme_options[second_blog_section_title]',
    )
);
    $wp_customize->add_setting('zion_blog_theme_options[show_second_blog_carousel]', [
        'type' => 'option',
        'default' => true,
        'default' => $zion_blog_options['show_second_blog_carousel'],
        'sanitize_callback' => 'zion_blog_sanitize_checkbox',
    ]);

    $wp_customize->add_control('zion_blog_theme_options[show_second_blog_carousel]', [
        'label' => esc_html__('Show Second Blog Carousel', 'zion-blog'),
        'type' => 'Checkbox',
        'priority' => 1,
        'section' => 'second_blog_carousel_section',
    ]);
    $wp_customize->add_setting(
        'zion_blog_theme_options[second_blog_carousel]',
        [
            'type' => 'option',
            'sanitize_callback' => 'zion_blog_sanitize_select',
            'default' => $zion_blog_options['second_blog_carousel'],
        ]
    );

    $wp_customize->add_control(
        'zion_blog_theme_options[second_blog_carousel]',
        [
            'section' => 'second_blog_carousel_section',
            'type' => 'select',
            'choices' => zion_blog_get_categories_select(),
            'label' => esc_html__('Select Category to show Posts', 'zion-blog'),
            'description' => esc_html__(
                'Max 5 Posts will be shown from the selected Category in Free Version',
                'zion-blog'
            ),
            'settings' => 'zion_blog_theme_options[second_blog_carousel]',
            'priority' => 1,
        ]
    );

    $wp_customize->add_section('prefooter_section', [
        'title' => esc_html__('Prefooter Section', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);

    $wp_customize->add_setting('zion_blog_theme_options[show_prefooter]', [
        'type' => 'option',
        'default' => true,
        'default' => $zion_blog_options['show_prefooter'],
        'sanitize_callback' => 'zion_blog_sanitize_checkbox',
    ]);

    $wp_customize->add_control('zion_blog_theme_options[show_prefooter]', [
        'label' => esc_html__('Show Prefooter Section', 'zion-blog'),
        'type' => 'Checkbox',
        'priority' => 1,
        'section' => 'prefooter_section',
    ]);


    $wp_customize->add_section('single_page_section', [
        'title' => esc_html__('Article Page Option', 'zion-blog'),
        'panel' => 'theme_options',
        'capability' => 'edit_theme_options',
    ]);

    $wp_customize->add_setting('zion_blog_theme_options[show_sidebar]', [
        'type' => 'option',
        'default' => true,
        'default' => $zion_blog_options['show_sidebar'],
        'sanitize_callback' => 'zion_blog_sanitize_checkbox',
    ]);

    $wp_customize->add_control('zion_blog_theme_options[show_sidebar]', [
        'label' => esc_html__('Show Sidebar in Single Article Page', 'zion-blog'),
        'type' => 'Checkbox',
        'priority' => 1,
        'section' => 'single_page_section',
    ]);
}
add_action('customize_register', 'zion_blog_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function zion_blog_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function zion_blog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function zion_blog_customize_preview_js() {
	wp_enqueue_script( 'zion-blog-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), _S_VERSION, true );
}
add_action( 'customize_preview_init', 'zion_blog_customize_preview_js' );
